<?php

namespace App\Http\Controllers;

use App\Models\AdditionalServices;
use App\Models\Program;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class AdditionalServicesController extends Controller
{
    //
    public function index()
    {
        $additionalServices = AdditionalServices::all();

        return view('system.additionalServices.index', compact('additionalServices'));
    }

    public function create()
    {
        $programs = Program::all();
        return view('system.additionalServices.add', compact('programs'));
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'ar_service_name' => 'required',
            'en_service_name' => 'required',
            'ar_description' => 'required',
            'en_description' => 'required',
            'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
            'price' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        try {
            if ($request->hasFile('image')) {
                $imageName = $request->image->getClientOriginalName();
                $request->image->move(public_path('uploads/additionalServices'), $imageName);
            }
            $service = new AdditionalServices();
            $service->program_id = $request->program_id;
            $service->ar_service_name = $request->ar_service_name;
            $service->en_service_name = $request->en_service_name;
            $service->ar_description = $request->ar_description;
            $service->en_description = $request->en_description;
            $service->image = $imageName;
            $service->price = $request->price;
            $service->save();

            session()->flash('Add', 'تم اضافة الخدمه');

            return redirect()->route('additionalServices.index')->with('success', 'Additional service created successfully.');
        } catch (Exception $e) {
            session()->flash('failed', 'فشل اضافة الخدمه');
            return redirect()->route('additionalServices.index');
        }
    }

    public function show($id)
    {
        $additionalService = AdditionalServices::findOrFail($id);

        return view('additional_services.show', compact('additionalService'));
    }

    public function edit($id)
    {
        $additionalService = AdditionalServices::findOrFail($id);
        $programs = Program::all();

        return view('system.additionalServices.edit', compact('additionalService', 'programs'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'ar_service_name' => 'required',
            'en_service_name' => 'required',
            'ar_description' => 'required',
            'en_description' => 'required',
            'price' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        try{
            $service = AdditionalServices::findOrFail($id);
            $service->program_id = $request->program_id;
            $service->ar_service_name = $request->ar_service_name;
            $service->en_service_name = $request->en_service_name;
            $service->ar_description = $request->ar_description;
            $service->en_description = $request->en_description;
            if ($request->hasFile('image')) {
                $imageName = $request->image->getClientOriginalName();
                $request->image->move(public_path('uploads/additionalServices'), $imageName);
                $service->image = $imageName;
            }
            $service->price = $request->price;
            $service->save();
            session()->flash('edit', 'تم تعديل الخدمه');

            return redirect()->route('additionalServices.index')->with('success', 'Additional service updated successfully.');
        }catch(Exception $e){
            session()->flash('failed', 'فشل تعديل الخدمه');
            return redirect()->route('additionalServices.index');
        }

    }

    public function destroy($id)
    {
        try{
            AdditionalServices::findOrFail($id)->delete();
            session()->flash('delete', 'تم حذف الخدمه');
            return redirect()->route('additionalServices.index')->with('success', 'Additional service deleted successfully.');
        }catch(Exception $e){
            session()->flash('failed', 'فشل حذف الخدمه');
            return redirect()->route('additionalServices.index');
        }

    }
}
