<?php

namespace App\Http\Controllers;

use App\Models\Coupons;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class CouponsController extends Controller
{
    public function index()
    {
        $coupons = Coupons::all();

        return view('system.coupons.index', compact('coupons'));
    }

    public function create()
    {
        return view('system.coupons.add');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'promocode' => 'required|unique:coupons',
            'points' => 'required',
            'ar_name' => 'required',
            'en_name' => 'required',
            'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
            'percentage' => 'required',
            'active' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        if ($request->hasFile('image')) {
            $imageName = $request->image->getClientOriginalName();
            $request->image->move(public_path('uploads/coupons'), $imageName);
        }

        Coupons::create([
            'promocode' => $request->promocode,
            'points' => $request->points,
            'ar_name' => $request->ar_name,
            'en_name' => $request->en_name,
            'image' => $imageName,
            'percentage' => $request->percentage,
            'active' => $request->active
        ]);
        session()->flash('Add', 'تم اضافة الكوبون');

        return redirect()->route('coupons.index')->with('success', 'Coupon created successfully.');
    }

    public function show($id)
    {
        $coupon = Coupons::findOrFail($id);

        return view('system.coupons.show', compact('coupon'));
    }

    public function edit($id)
    {
        $coupon = Coupons::findOrFail($id);

        return view('system.coupons.edit', compact('coupon'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            // 'promocode' => 'required|unique:coupons',
            'points' => 'required',
            'ar_name' => 'required',
            'en_name' => 'required',
            'percentage' => 'required',
            'active' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        if ($request->hasFile('image')) {
            $imageName = $request->image->getClientOriginalName();
            $request->image->move(public_path('uploads/coupons'), $imageName);
        }else{
            $imageName=Coupons::findOrFail($id)->image;
        }
        Coupons::findOrFail($id)->update([
            // 'promocode' => $request->promocode,
            'points' => $request->points,
            'ar_name' => $request->ar_name,
            'en_name' => $request->en_name,
            'image' => $imageName,
            'percentage' => $request->percentage,
            'active' => $request->active
        ]);
        session()->flash('edit', 'تم تعديل الكوبون');

        return redirect()->route('coupons.index')->with('success', 'Coupon updated successfully.');
    }

    public function destroy($id)
    {
        try{
            Coupons::findOrFail($id)->delete();
            session()->flash('delete', 'تم حذف الكوبون');

            return redirect()->route('coupons.index')->with('success', 'Coupon deleted successfully.');

        }catch(Exception $e){
            session()->flash('failed', 'فشل حذف الكوبون');

            return redirect()->route('coupons.index');
        }

    }
}
