<?php

namespace App\Http\Controllers;

use App\Models\Customer;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;

class CustomerController extends Controller
{
    //
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $customers = Customer::get();
        return view('system.customers.index',compact('customers'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('system.customers.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name'=> 'required',
            'email'=> ['required', 'string', 'email', 'max:255', 'unique:customers'],
            'phone_number'=> 'required|unique:customers',
            'password'=> 'required',
            'age'=> 'required',
            'nationality'=> 'required',
            'country'=> 'required',
            'governorate'=> 'required',
            'profile_photo_path'=> 'image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $imageName = null;
        if ($request->hasFile('profile_photo_path')) {
            $imageName = $request->profile_photo_path->getClientOriginalName();
            $request->profile_photo_path->move(public_path('uploads/profiles'), $imageName);
        }
        Customer::create([
            'name'=> $request->name,
            'email'=>$request->email,
            'phone_number'=>$request->phone_number,
            'password'=>Hash::make($request->password),
            'age'=>$request->age,
            'nationality'=>$request->nationality,
            'country'=>$request->country,
            'governorate'=>$request->governorate,
            'profile_photo_path'=>$imageName
        ]);

        session()->flash('Add', 'تم اضافة العميل ');
        return  redirect()->route('customers.index');

    }

    /**
     * Display the specified resource.
     */
    public function show()
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $customer= Customer::findorfail($id);
        return view('system.customers.edit',compact('customer'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'name'=> 'required',
            'email'=> 'required',
            'phone_number'=> 'required',
            'age'=> 'required',
            'nationality'=> 'required',
            'country'=> 'required',
            'governorate'=> 'required',
            'points'=> 'required',
            'isVerified'=> 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $customer= Customer::findorfail($id);

        $customer->update([
            'name'=> $request->name,
            'email'=>$request->email,
            'phone_number'=>$request->phone_number,
            'age'=>$request->age,
            'nationality'=>$request->nationality,
            'country'=>$request->country,
            'governorate'=>$request->governorate,
            'points'=>$request->points,
            'isVerified'=>$request->isVerified
        ]);
        if(isset($request->password)){
            $customer->update([
                'password'=>Hash::make($request->password)
            ]);
        }

        session()->flash('edit', 'تم تعديل بيانات العميل ');

        return  redirect()->route('customers.index');

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {

        try{
            Customer::findorfail($id)->delete();
            session()->flash('delete', 'تم حذف العميل بنجاح');
            return  redirect()->route('customers.index');

        }catch(Exception $e){
            session()->flash('failed', 'فشل حذف العميل بنجاح');
            return  redirect()->route('customers.index');
        }
    }
}
