<?php

namespace App\Http\Controllers;

use App\Models\package;
use App\Models\PackageProgram;
use App\Models\packageTypes;
use App\Models\Program;
use App\Models\TouristCity;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;


class PackageController extends Controller
{
    //

    public function index()
    {
        $packages = package::all();

        return view('system.packages.index', compact('packages'));
    }

    public function create()
    {

        $programs = Program::all();
        return view('system.packages.add', compact('programs'));
    }
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'ar_name' => 'required',
            'en_name' => 'required',
            'ar_description' => 'required',
            'en_description' => 'required',
            'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
            'total' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
            'customer_id' => 'required',
            'is_approved' => 'required',
            'ready_to_publish' => 'required',
            'programs_ids' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        try {
            $package = new Package();
            $package->ar_name = $request->ar_name;
            $package->en_name = $request->en_name;
            $package->ar_description = $request->ar_description;
            $package->en_description = $request->en_description;
            $package->total = $request->total;
            $package->start_date = $request->start_date;
            $package->end_date = $request->end_date;
            $package->customer_id = $request->customer_id;
            $package->is_approved = $request->is_approved;
            $package->ready_to_publish = $request->ready_to_publish;
            if ($request->hasFile('image')) {
                $image = $request->file('image');
                $imageName = $image->getClientOriginalName();
                $image->move(public_path('uploads/packages'), $imageName);
                $package->image = $imageName;
            }
            $package->save();

            if (!empty($request->programs_ids)) {
                foreach ($request->programs_ids as $key => $id) {
                    $packageProgram = new PackageProgram();
                    $packageProgram->package_id = $package->id;
                    $packageProgram->program_id = $id;
                    $packageProgram->save();
                }
            }

            session()->flash('Add', 'تم اضافة الباكدج');
            return redirect()->route('packages.index');
        } catch (Exception $e) {
            session()->flash('failed', 'فشل اضافة الباكدج');
            return redirect()->route('packages.index');
        }
    }

    public function show($id)
    {
        $package = Package::findOrFail($id);
        return view('system.packages.show', compact('package'));
    }

    public function edit(Request $request, $id)
    {
        $package = package::findOrFail($id);
        $programs = Program::all();
        return view('system.packages.edit', compact('package', 'programs'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'ar_name' => 'required',
            'en_name' => 'required',
            'ar_description' => 'required',
            'en_description' => 'required',
            'image' => 'image|mimes:jpeg,png,jpg,gif|max:2048',
            'total' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
            'is_approved' => 'required',
            'ready_to_publish' => 'required',
            'programs_ids' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        try{
            $package = package::find($id);
            $package->ar_name = $request->ar_name;
            $package->en_name = $request->en_name;
            $package->ar_description = $request->ar_description;
            $package->en_description = $request->en_description;
            $package->total = $request->total;
            $package->start_date = $request->start_date;
            $package->end_date = $request->end_date;
            $package->customer_id = isset($request->customer_id)?$request->customer_id:null;
            $package->is_approved = $request->is_approved;
            $package->ready_to_publish = $request->ready_to_publish;
            if ($request->hasFile('image')) {
                $image = $request->file('image');
                $imageName = $image->getClientOriginalName();
                $image->move(public_path('uploads/packages'), $imageName);
                $package->image = $imageName;
            }

            $deletedRows = PackageProgram::where('package_id', $package->id)->delete();

            if (!empty($request->programs_ids)) {
                foreach ($request->programs_ids as $key => $id) {
                    $packageProgram = new PackageProgram();
                    $packageProgram->package_id = $package->id;
                    $packageProgram->program_id = $id;
                    $packageProgram->save();
                }
            }

            $package->save();

            session()->flash('edit', 'تم تعديل الباكدج');
            return redirect()->route('packages.index');
        }catch(Exception $e){
            session()->flash('failed', 'فشل تعديل الباكدج');
            return redirect()->route('packages.index');
        }
    }

    public function destroy($id)
    {
        try {
            Package::findOrFail($id)->delete();
            PackageProgram::where('package_id', $id)->delete();
            session()->flash('delete', 'تم حذف الباكدج');
            return redirect()->route('packages.index')->with('success', 'package deleted successfully.');
        } catch (Exception $e) {
            session()->flash('failed', 'فشل حذف الباكدج');
            return redirect()->route('packages.index');
        }
    }

}
