<?php

namespace App\Http\Controllers;

use App\Models\Payments;
use App\Models\Reservation;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class PaymentsController extends Controller
{
    public function index()
    {
        $payments = Payments::all();

        return view('system.payments.index', compact('payments'));
    }

    public function create()
    {

        $reservations = Reservation::get();
        return view('system.payments.add', compact('reservations'));
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'reservation_id' => 'required',
            'user_id' => 'required',
            'amount' => 'required',
            'type' => 'required',
            'date' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Payments::create($request->all());
        session()->flash('Add', 'تم اضافة عملية دفع ');

        return  redirect()->route('payments.index');
    }

    public function show($id)
    {
        $payment = Payments::findOrFail($id);
        return view('system.payments.show', compact('payment'));
    }

    public function edit($id)
    {
        $payment = Payments::findOrFail($id);
        return view('system.payments.edit', compact('payment'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'reservation_id' => 'required',
            'user_id' => 'required',
            'amount' => 'required',
            'type' => 'required',
            'date' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Payments::findOrFail($id)->update($request->all());
        session()->flash('edit', 'تم تعديل عملية الدفع  ');

        return  redirect()->route('payments.index');
    }

    public function destroy($id)
    {

        try{
            Payments::findOrFail($id)->delete();
            session()->flash('delete', 'تم حذف عملية الدفع ');
            return  redirect()->route('payments.index');
        }catch(Exception $e){

        session()->flash('failed', 'فشل حذف عملية الدفع ');
        return  redirect()->route('payments.index');
        }
    }
}
