<?php

namespace App\Http\Controllers;

use App\Models\Program;
use App\Models\ProgramTypes;
use App\Models\TouristCity;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProgramController extends Controller
{
    public function index()
    {
        $programs = Program::all();

        return view('system.programs.program', compact('programs'));
    }

    public function create()
    {
        $types = ProgramTypes::all();
        $touristCities = TouristCity::all();
        return view('system.programs.add_program', compact('types', 'touristCities'));
    }
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'type_id' => 'required',
            'ar_program_name' => 'required',
            'en_program_name' => 'required',
            'ar_description' => 'required',
            'en_description' => 'required',
            'images.*' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
            'town' => 'required',
            'reservation_price' => 'required',
            'payment_duration' => 'required',
            'available_from' => 'required',
            'available_to' => 'required',
            'status' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        try {
            $program = new Program();
            $imagesArray = array();
            if ($request->hasFile('images')) {
                foreach ($request->file('images') as $image) {
                    $imageName = $image->getClientOriginalName();
                    $image->move(public_path('uploads/programs'), $imageName);

                    $imagesArray[] = $imageName;
                }
            }

            $program->type_id = $request->type_id;
            $program->ar_program_name = $request->ar_program_name;
            $program->en_program_name = $request->en_program_name;
            $program->ar_description = $request->ar_description;
            $program->en_description = $request->en_description;
            $program->images = implode(',', $imagesArray);
            $program->town = $request->town;
            if ($request->tourist_city_id != null) {
                $program->tourist_city_id = $request->tourist_city_id;
            }
            if ($request->location != null) {
                $program->location = $request->location;
            }
            $program->reservation_price = $request->reservation_price;
            $program->payment_duration = $request->payment_duration;
            $program->available_from = $request->available_from;
            $program->available_to = $request->available_to;

            $program->status = $request->status;
            $program->save();
            session()->flash('Add', 'تم اضافة البرنامج');
            return redirect()->route('programs.index')->with('success', 'Program created successfully.');
        } catch (Exception $e) {
            session()->flash('failed', 'فشل اضافة البرنامج');
            return redirect()->route('programs.index')->with('failed', 'Program creation failed.');
        }
    }

    public function show($id)
    {
        $program = Program::findOrFail($id);
        $types = ProgramTypes::all();

        return view('system.programs.show', compact('program', 'types'));
    }

    public function edit(Request $request, $id)
    {
        $program = Program::findOrFail($id);
        $types = ProgramTypes::all();
        $touristCities = TouristCity::all();

        return view('system.programs.edit', compact('program', 'types', 'touristCities'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'type_id' => 'required',
            'ar_program_name' => 'required',
            'en_program_name' => 'required',
            'ar_description' => 'required',
            'en_description' => 'required',
            'town' => 'required',
            'reservation_price' => 'required',
            'payment_duration' => 'required',
            'available_from' => 'required',
            'available_to' => 'required',
            'status' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $program = Program::find($id);
        $program->type_id = $request->type_id;
        $program->ar_program_name = $request->ar_program_name;
        $program->en_program_name = $request->en_program_name;
        $program->ar_description = $request->ar_description;
        $program->en_description = $request->en_description;
        $program->town = $request->town;
        if ($request->tourist_city_id != null) {
            $program->tourist_city_id = $request->tourist_city_id;
        }
        if ($request->location==null) {
            $program->location = null;
        }else{
            $program->location = $request->location;
        }
        $program->reservation_price = $request->reservation_price;
        $program->payment_duration = $request->payment_duration;
        $program->available_from = $request->available_from;
        $program->available_to = $request->available_to;
        $program->status = $request->status;
        $program->save();
        session()->flash('edit', 'تم تعديل البرنامج');

        return redirect()->route('programs.index')->with('success', 'Program updated successfully.');
    }

    public function destroy($id)
    {
        try{
            Program::findOrFail($id)->delete();
            session()->flash('delete', 'تم حذف البرنامج');

            return redirect()->route('programs.index')->with('success', 'Program deleted successfully.');

        }catch(Exception $e){

            session()->flash('failed', 'فشل حذف البرنامج');
            return redirect()->route('programs.index');
        }
    }
    public function addVisitor($id)
    {
        $program = Program::findOrFail($id);
        $program->visitors = ($program->visitors) + 1;
        $program->save();
    }
}
