<?php

namespace App\Http\Controllers;

use App\Models\Program;
use App\Models\ProgramExperiences;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProgramExperiencesController extends Controller
{
    public function index()
    {
        $experiences = ProgramExperiences::all();

        return view('system.experiences.index', compact('experiences'));
    }

    public function create()
    {
        $programs = Program::get();
        return view('system.experiences.add', compact('programs'));
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'media_type' => 'required',
            'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048'
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        try {
            $experience = new ProgramExperiences();
            if ($request->hasFile('image')) {
                $image = $request->file('image');
                $imageName = $image->getClientOriginalName();
                $image->move(public_path('uploads/experiences/images'), $imageName);
                $experience->path=$imageName;
            }
            $experience->program_id=$request->program_id;
            $experience->media_type=$request->media_type;

            $experience->save();
            session()->flash('Add', 'تم اضافة تجربة البرنامج');
            return redirect()->route('experiences.index');
        } catch (Exception $e) {
            session()->flash('failed', 'فشل اضافة تجربة البرنامج');
            return redirect()->route('experiences.index');
        }
    }

    public function show($id)
    {
        $experience = ProgramExperiences::findOrFail($id);

        return view('system.experiences.show', compact('experience'));
    }

    public function edit($id)
    {
        $experience = ProgramExperiences::findOrFail($id);
        $programs = Program::get();

        return view('system.experiences.edit', compact('experience','programs'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'media_type' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $experience = ProgramExperiences::findOrFail($id);

        if ($request->hasFile('image') && $request->file('image')!=null) {

            $image = $request->file('image');
            $imageName = $image->getClientOriginalName();
            $image->move(public_path('uploads/experiences/images'), $imageName);
            $experience->path=$imageName;
        }

        $experience->program_id=$request->program_id;
        $experience->media_type=$request->media_type;

        $experience->save();

        session()->flash('edit', 'تم تعديل تجربة البرنامج');
        return redirect()->route('experiences.index');
    }

    public function destroy($id)
    {
        try{
            ProgramExperiences::findOrFail($id)->delete();
            session()->flash('delete', 'تم حذف تجربة البرنامج');
            return redirect()->route('experiences.index');
        }catch(Exception $e){
            session()->flash('failed', 'فشل حذف تجربة البرنامج');
            return redirect()->route('experiences.index');
        }
    }
}
