<?php

namespace App\Http\Controllers;

use App\Models\ProgramTypes;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProgramTypesController extends Controller
{
    public function index()
    {
        $programTypes = ProgramTypes::all();

        return view('system.programTypes.types', compact('programTypes'));
    }

    public function create()
    {
        return view('system.programTypes.add');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'ar_type' => 'required',
            'en_type' => 'required',
            'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        if ($request->hasFile('image')) {
            $imageName = $request->image->getClientOriginalName();
            $request->image->move(public_path('uploads/programTypes'), $imageName);
        }

        $type=new ProgramTypes();
        $type->ar_type=$request->ar_type;
        $type->en_type=$request->en_type;
        $type->image=$imageName;
        $type->save();
        session()->flash('add', 'تم اضافه النوع');

        return redirect()->route('programTypes.index')->with('success', 'Program type created successfully.');
    }

    public function show($id)
    {
        $programType = ProgramTypes::findOrFail($id);

        return view('program_types.show', compact('programType'));
    }

    public function edit($id)
    {
        $programType = ProgramTypes::findOrFail($id);

        return view('system.programTypes.edit', compact('programType'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'ar_type' => 'required',
            'en_type' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $type=ProgramTypes::findOrFail($id);
        $type->ar_type=$request->ar_type;
        $type->en_type=$request->en_type;
        if ($request->hasFile('image')) {
            $imageName = $request->image->getClientOriginalName();
            $request->image->move(public_path('uploads/programTypes'), $imageName);
            $type->image=$imageName;
        }
        $type->save();
        session()->flash('edit', 'تم تعديل النوع');

        return redirect()->route('programTypes.index')->with('success', 'Program type updated successfully.');
    }

    public function destroy($id)
    {

        try {
            ProgramTypes::findOrFail($id)->delete();
            session()->flash('delete', 'تم حذف النوع');

            return redirect()->route('programTypes.index')->with('success', 'Program type deleted successfully.');
        } catch (Exception $e) {
            session()->flash('failed', 'فشل حذف النوع');
            return redirect()->route('programTypes.index');

        }

    }}
