<?php

namespace App\Http\Controllers;

use App\Models\AdditionalServices;
use App\Models\Customer;
use App\Models\Program;
use App\Models\Reservation;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ReservationController extends Controller
{
    /**
     * Display a listing of the reservations.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $reservations = Reservation::all();
        return view('system.reservations.index', compact('reservations'));
    }

    /**
     * Show the form for creating a new reservation.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $programs = Program::get();
        $customers = Customer::get();
        // $additonalServices = AdditionalServices::get();
        return view('system.reservations.add', compact('programs', 'customers'));
    }



    /**
     * Store a newly created reservation in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|integer',
            'program_id' => 'required|integer',
            'notes' => 'nullable|string',
            'total_price' => 'required|numeric',
            'date_of_reservation' => 'required|date',
            'status' => 'required|string',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Reservation::create($request->all());

        session()->flash('Add', 'تم اضافة الحجز ');
        return  redirect()->route('system.reservations.index');
    }

    /**
     * Display the specified reservation.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $reservation = Reservation::findOrFail($id);
        return view('system.reservations.show', compact('reservation'));
    }

    /**
     * Show the form for editing the specified reservation.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $reservation = Reservation::findOrFail($id);
        return view('system.reservations.edit', compact('reservation'));
    }

    /**
     * Update the specified reservation in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|integer',
            'program_id' => 'required|integer',
            'notes' => 'nullable|string',
            'total_price' => 'required|numeric',
            'date_of_reservation' => 'required|date',
            'status' => 'required|string',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Reservation::findOrFail($id)->update($request->all());

        session()->flash('edit', 'تم تعديل الحجز ');
        return  redirect()->route('system.reservations.index');
    }

    /**
     * Remove the specified reservation from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {

        try{
            Reservation::findOrFail($id)->delete();
            session()->flash('delete', 'تم حذف الحجز ');
            return  redirect()->route('system.reservations.index');
        }catch(Exception $e){
            session()->flash('failed', 'فشل حذف الحجز ');
            return  redirect()->route('system.reservations.index');
        }
    }

    public function additionalServicesAjax($id)
    {
        $additonalServices = AdditionalServices::where('program_id', $id)->get();

        return response()->json(['success' => true, 'data' => $additonalServices]);
    }

    public function ajaxGetReservation(Request $request)
    {
        $data = $request->input('data');
        $id = $data['id'];
        $reservation = Reservation::find($id);
        return response()->json(['success' => true, 'data' => $reservation]);
    }
    public function reservationInfoAjax($id)
    {
        $reservation = Reservation::find($id);
        $customer = Customer::find($reservation->user_id);
        $program = Program::find($reservation->program_id);
        $data['reservation']=$reservation;
        $data['customer']=$customer;
        $data['program']=$program;

        return response()->json(['success' => true, 'data' => $data]);
    }
}
