<?php

namespace App\Http\Controllers;

use App\Models\TouristCity;
use Illuminate\Http\Request;
use Exception;
use Illuminate\Support\Facades\Validator;

class TouristCityController extends Controller
{
    //
    public function index()
    {
        $cities = TouristCity::all();

        return view('system.touristCity.index', compact('cities'));
    }

    public function create()
    {

        return view('system.touristCity.add');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'ar_city' => 'required',
            'en_city' => 'required'
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        try{
            $city = new TouristCity();
            $city->ar_city = $request->ar_city;
            $city->en_city = $request->en_city;
            $city->save();
            session()->flash('Add', 'تم اضافة المدينة السياحية ');
            return redirect()->route('touristCity.index')->with('success', 'تم اضافة المدينة السياحية ');
        }catch(Exception $e){
            session()->flash('failed', 'فشل اضافة المدينة السياحية');
            return redirect()->route('touristCity.index')->with('failed', 'فشل اضافة المدينة السياحية');

        }
    }

    public function show($id)
    {

    }

    public function edit($id)
    {
        $city = TouristCity::findOrFail($id);
        return view('system.touristCity.edit', compact('city'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'ar_city' => 'required',
            'en_city' => 'required'
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        TouristCity::findOrFail($id)->update($request->all());
        session()->flash('edit', 'تم تعديل المدينة السياحية');

        return redirect()->route('touristCity.index')->with('success', 'تم تعديل المدينة السياحية');
    }

    public function destroy($id)
    {
        try{
            TouristCity::findOrFail($id)->delete();
            session()->flash('delete', 'تم حذف المدينة السياحية');

            return redirect()->route('touristCity.index')->with('success', 'تم حذف المدينة السياحية');

        }catch(Exception $e){
            session()->flash('failed', 'فشل حذف المدينة السياحية');
            return redirect()->route('touristCity.index');
        }
    }
}
