<?php

namespace App\Http\Controllers\api;

use App\Models\AdditionalServices;
use App\Models\Program;
use App\Traits\ApiResponseTrait;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class AdditionalServicesController extends Controller
{
    use ApiResponseTrait;

    //
    public function index()
    {
        $additionalServices = AdditionalServices::all();

        return view('system.additionalServices.index', compact('additionalServices'));
    }

    public function create()
    {
        $programs = Program::all();
        return view('system.additionalServices.add',compact('programs'));
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'service_name' => 'required',
            'description' => 'required',
            'image' => 'required',
            'price' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        AdditionalServices::create($request->all());
        session()->flash('Add', 'تم اضافة الخدمه');

        return redirect()->route('additionalServices.index')->with('success', 'Additional service created successfully.');
    }

    public function show($id)
    {
        $additionalService = AdditionalServices::findOrFail($id);

        return view('additional_services.show', compact('additionalService'));
    }

    public function edit($id)
    {
        $additionalService = AdditionalServices::findOrFail($id);
        $programs = Program::all();

        return view('system.additionalServices.edit', compact('additionalService','programs'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'service_name' => 'required',
            'description' => 'required',
            'image' => 'required',
            'price' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        AdditionalServices::findOrFail($id)->update($request->all());
        session()->flash('edit', 'تم تعديل الخدمه');

        return redirect()->route('additionalServices.index')->with('success', 'Additional service updated successfully.');
    }

    public function destroy($id)
    {
        AdditionalServices::findOrFail($id)->delete();
        session()->flash('delete', 'تم حذف الخدمه');

        return redirect()->route('additionalServices.index')->with('success', 'Additional service deleted successfully.');
    }
}
