<?php

namespace App\Http\Controllers\api;

use App\Models\Customer;
use App\Traits\ApiResponseTrait;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;

class CustomerController extends Controller
{
    use ApiResponseTrait;

    //
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $customers = Customer::get();
        return view('system.customers.index',compact('customers'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('system.customers.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name'=> 'required',
            'email'=> 'required',
            'phone_number'=> 'required',
            'password'=> 'required',
            'age'=> 'required',
            'nationality'=> 'required',
            'country'=> 'required',
            'governorate'=> 'required',
            'profile_photo_path'=> 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        Customer::create([
            'name'=> $request->name,
            'email'=>$request->email,
            'phone_number'=>$request->phone_number,
            'password'=>Hash::make($request->password),
            'age'=>$request->age,
            'nationality'=>$request->nationality,
            'country'=>$request->country,
            'governorate'=>$request->governorate,
            'profile_photo_path'=>$request->profile_photo_path
        ]);

        session()->flash('Add', 'تم اضافة العميل ');
        return  redirect()->route('customers.index');

    }

    /**
     * Display the specified resource.
     */
    public function show()
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $customer= Customer::findorfail($id);
        return view('system.customers.edit',compact('customer'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'name'=> 'required',
            'email'=> 'required',
            'phone_number'=> 'required',
            'age'=> 'required',
            'nationality'=> 'required',
            'country'=> 'required',
            'governorate'=> 'required',
            'points'=> 'required',
            'profile_photo_path'=> 'required',
            'isVerified'=> 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $customer= Customer::findorfail($id);

        $customer->update([
            'name'=> $request->name,
            'email'=>$request->email,
            'phone_number'=>$request->phone_number,
            'age'=>$request->age,
            'nationality'=>$request->nationality,
            'country'=>$request->country,
            'governorate'=>$request->governorate,
            'points'=>$request->points,
            'profile_photo_path'=>$request->profile_photo_path,
            'isVerified'=>$request->isVerified
        ]);
        if(isset($request->password)){
            $customer->update([
                'password'=>Hash::make($request->password)
            ]);
        }

        session()->flash('edit', 'تم تعديل بيانات العميل ');

        return  redirect()->route('customers.index');

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        Customer::findorfail($id)->delete();
        session()->flash('delete', 'تم حذف العميل بنجاح');
        return  redirect()->route('customers.index');
    }
}
