<?php

namespace App\Http\Controllers\api;

use App\Models\AdditionalServices;
use App\Models\Program;
use App\Models\Favorite;
use App\Models\ProgramTypes;
use App\Models\TouristCity;
use App\Models\ProgramExperiences;
use App\Traits\ApiResponseTrait;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProgramController extends Controller
{
    use ApiResponseTrait;

    public function index(Request $request)
    {
        try {
            $programs = Program::get();
            foreach ($programs as $program) {
                $program['type'] = $program->type;
                $program['tourist_city'] = $program->TouristCity;
                $program['additional_services'] = $program->AdditionalServices;
                $program['program_experiences'] = $program->programExperiences;
                $program['offer'] = $program->Offer;
            }
            return $this->returnData('programs', $programs, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no programs");
        }
    }
    public function show(Request $request)
    {
        try {
            $program = Program::findOrFail($request->id);
            $program['type'] = $program->type;
            $program['tourist_city'] = $program->TouristCity;
            $program['additional_services'] = $program->AdditionalServices;
            $program['program_experiences'] = $program->programExperiences;
            $program['offer'] = $program->Offer;

            $this->addVisitor($request->id);
            return $this->returnData('program', $program, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no program");
        }
    }

    public function showFromFav(Request $request)
    {

        try {
        $favs = Favorite::where('user_id', $request->user_id)->get();
        if($favs->isEmpty()){
            return $this->error(0, "you have no favorites");

        }
        $typeIds = $favs->pluck('type_id')->toArray();

        $programs = Program::whereIn('type_id', $typeIds)->get();

        foreach ($programs as $program) {
            $program->type = ProgramTypes::find($program->type_id);
            $program->tourist_city = TouristCity::find($program->tourist_city_id);
            $program->additional_services = AdditionalServices::where('program_id', $program->id)->get();
            $program->program_experiences = ProgramExperiences::where('program_id', $program->id)->get();
            $program->offer = $program->Offer;
        }

        return $this->returnData('programs', $programs, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no programs");
        }
    }

    public function addVisitor($id)
    {
        $program = Program::findOrFail($id);
        $program->visitors = ($program->visitors) + 1;
        $program->save();
    }
}
