<?php

namespace App\Http\Controllers\api;

use App\Models\Program;
use App\Models\ProgramTypes;
use App\Traits\ApiResponseTrait;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProgramTypesController extends Controller
{
    use ApiResponseTrait;

    public function index()
    {
        try {
            $programTypes = ProgramTypes::all();
            return $this->returnData('programTypes', $programTypes, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no program types");
        }
        
    }
    public function getProgramsWithType(Request $request){
        
        try {
            $programs = Program::where('type_id',$request->type_id)->get();
            foreach($programs as $program){
                $program['type'] = $program->type;
                $program['tourist_city'] = $program->TouristCity;
                $program['additional_services'] = $program->AdditionalServices;
                $program['program_experiences'] = $program->programExperiences;
                $program['offer'] = $program->Offer;                   
            }
            return $this->returnData('programs', $programs, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no programs");
        }
    }
    public function create()
    {
        return view('system.programTypes.add');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'type' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        ProgramTypes::create($request->all());
        session()->flash('add', 'تم اضافه النوع');

        return redirect()->route('programTypes.index')->with('success', 'Program type created successfully.');
    }

    public function show($id)
    {
        $programType = ProgramTypes::findOrFail($id);

        return view('program_types.show', compact('programType'));
    }

    public function edit($id)
    {
        $programType = ProgramTypes::findOrFail($id);

        return view('system.programTypes.edit', compact('programType'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'type' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        ProgramTypes::findOrFail($id)->update($request->all());
        session()->flash('edit', 'تم تعديل النوع');

        return redirect()->route('programTypes.index')->with('success', 'Program type updated successfully.');
    }

    public function destroy($id)
    {
        ProgramTypes::findOrFail($id)->delete();
        session()->flash('delete', 'تم حذف النوع');

        return redirect()->route('programTypes.index')->with('success', 'Program type deleted successfully.');
    }}
