<?php

namespace App\Http\Controllers\api;

use App\Models\Customer;
use App\Models\Program;
use App\Models\Rating;
use App\Models\User;
use App\Traits\ApiResponseTrait;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class RatingController extends Controller
{
    use ApiResponseTrait;

    public function index()
    {
        $ratings = Rating::all();
        return view('system.rating.index', compact('ratings'));
    }

    public function create()
    {
        $programs = Program::all();
        $customers = Customer::all();
        return view('system.rating.add', compact('programs', 'customers'));
    }

    public function store(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'user_id' => 'required',
            'rate' => 'required',
            'comment' => 'required',
            
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        try {
            $currentDate = date('Y-m-d');
            $rate = new Rating();
            $rate->program_id=$request->program_id;
            $rate->user_id=$request->user_id;
            $rate->rate=$request->rate;
            $rate->comment = $request->comment;
            $rate->date = $currentDate;
            $rate->save();
            $this->incrementRating($request->program_id);
            
            session()->flash('Add', 'تم اضافة تقييم للبرنامج');

            return redirect()->route('rating.index')->with('success', 'Rating created successfully.');
        } catch (Exception $e) {

            session()->flash('failed', 'فشل اضافة تقييم للبرنامج');
            return redirect()->route('rating.index')->with('success', 'Rating created successfully.');
        }
    }

    public function show($id)
    {
        $rating = Rating::findOrFail($id);

        return view('system.rating.show', compact('rating'));
    }

    public function edit($id)
    {
        $rating = Rating::findOrFail($id);
        $programs = Program::all();
        $customers = Customer::all();
        return view('system.rating.edit', compact('rating','programs','customers'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'user_id' => 'required',
            'rate' => 'required',
            'comment' => 'required',
            // 'date' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        try {
            
            $rate = Rating::findOrFail($id);
            $rate->program_id=$request->program_id;
            $rate->user_id=$request->user_id;
            $rate->rate=$request->rate;
            $rate->comment = $request->comment;
            $rate->save();
            session()->flash('edit', 'تم تعديل تقييم للبرنامج');

            return redirect()->route('rating.index')->with('success', 'Rating created successfully.');
        } catch (Exception $e) {

            session()->flash('failed', 'فشل تعديل تقييم للبرنامج');
            return redirect()->route('rating.index')->with('success', 'Rating created successfully.');
        }

        
    }

    public function destroy($id)
    {
        $rate=Rating::findOrFail($id);
        $this->decrementRating($rate->program_id);
        $rate->delete();
        session()->flash('delete', 'تم حذف تقييم البرنامج');
        return redirect()->route('rating.index')->with('success', 'Rating deleted successfully.');
    }

    public function incrementRating($id){
        $program = Program::findOrFail($id);
        $program->rate = ($program->rate) + 1;
        $program->save();
    }
    public function decrementRating($id){
        $program = Program::findOrFail($id);
        if($program->rate!=0){
            $program->rate = ($program->rate) - 1;
        }
        $program->save();
    }
}
