<?php

namespace App\Http\Controllers\api;

use App\Models\AdditionalServices;
use App\Models\Customer;
use App\Models\Program;
use App\Models\Reservation;
use App\Models\ReservationAdditionalServices;
use App\Traits\ApiResponseTrait;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ReservationController extends Controller
{
    use ApiResponseTrait;
    public function add(Request $request)
    {
        $rules = [
            'user_id' => 'required|integer',
            'program_id' => 'required|integer',
            'notes' => 'nullable|string',
            'date_of_reservation' => 'required|date',
            // 'status' => 'required|string',
        ];
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }
        try {

            $currentDate = date("Y-m-d");
            $program = Program::find($request->program_id);
            $program_available_from = $program->available_from;
            $program_available_to = $program->available_from;

            $availableFromTimestamp = strtotime($program_available_from);
            $availableToTimestamp = strtotime($program_available_to);
            $currentDateTimestamp = strtotime($currentDate);
            $reservationTimestamp = strtotime($request->date_of_reservation);
            if($program->status==0){
                return $this->error(0, "this program is not available now");
            }
            if ($reservationTimestamp >= $currentDateTimestamp && $currentDateTimestamp >= $availableFromTimestamp && $currentDateTimestamp <= $availableToTimestamp) {
                $reservation = new Reservation();

                $total_price = $this->getProgramPrice($program->id,$reservationTimestamp);
                //check for ofers

                $reservation->user_id = $request->user_id;
                $reservation->program_id = $request->program_id;
                $reservation->notes = $request->notes;
                $reservation->total_price = $total_price;
                $reservation->date_of_reservation = $request->date_of_reservation;
                $reservation->status = 0;
                $reservation->save();

                if (isset($request->additional_service_ids)) {
                    $arrayString = $request->input('additional_service_ids');
                    $array = explode(',', $arrayString);

                    foreach ($array as $additional_service_id) {
                        $res_additional_service = new ReservationAdditionalServices();
                        $res_additional_service->reservation_id = $reservation->id;
                        $res_additional_service->additional_service_id = $additional_service_id;
                        $total_price = ((Double)$total_price)+((Double)AdditionalServices::find($additional_service_id)->price);
                        $res_additional_service->save();
                    }
                    $reservation->total_price = $total_price;
                    $reservation->save();

                }
                return $this->success(0, "the reservation date been booked successfully");
            } else {
                return $this->error(0, "this program is not available in this date");
            }
        } catch (Exception $e) {
            return $this->error(0, "some thing went wrong");
        }
    }
    public function cancel(Request $request)
    {
        $rules = [
            "reservation_id" => "required",
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }

        try {
            return $this->success(0, "added to favorites successfully");
        } catch (Exception $e) {
            return $this->error(0, "their is no favorites");
        }
    }
    public function view(Request $request)
    {
        $rules = [
            "reservation_id" => "required",
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }

        try {
            $reservation = Reservation::find($request->reservation_id);
            $reservation['program'] = $reservation->Program;
            $additionals = ReservationAdditionalServices::where('reservation_id', $reservation->id)->get();
            $services = [];
            foreach ($additionals as $additional) {
                $services[] = $additional->AdditionalServices;
            }
            $reservation['reservation_additional_services'] = $services;
            return $this->returnData('reservation', $reservation, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no reservation with this id");
        }
    }
    public function viewAll(Request $request)
    {
        $rules = [
            "user_id" => "required",
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }

        try {
            $reservations = Reservation::where('user_id', $request->user_id)->get();
            foreach ($reservations as $reservation) {
                $reservation['program'] = $reservation->Program;
                $additionals = ReservationAdditionalServices::where('reservation_id', $reservation->id)->get();
                $services = [];
                foreach ($additionals as $additional) {
                    $services[] = $additional->AdditionalServices;
                }
                $reservation['reservation_additional_services'] = $services;
            }
            return $this->returnData('reservations', $reservations, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no favorites");
        }
    }
    public function pending(Request $request)
    {
        $rules = [
            "user_id" => "required",
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }

        try {
            $reservations = Reservation::where('user_id', $request->user_id)->where('status', 0)->get();
            foreach ($reservations as $reservation) {
                $reservation['program'] = $reservation->Program;
                $additionals = ReservationAdditionalServices::where('reservation_id', $reservation->id)->get();
                $services = [];
                foreach ($additionals as $additional) {
                    $services[] = $additional->AdditionalServices;
                }
                $reservation['reservation_additional_services'] = $services;
            }
            return $this->returnData('reservations', $reservations, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no favorites");
        }
    }
    public function getProgramPrice($id,$date){
        $final_price = 0;
        $program = Program::find($id);
        $offer = $program->Offer;
        if($offer){
            $availableFromTimestamp = strtotime($offer->offer_start_date);
            $availableToTimestamp = strtotime($offer->offer_end_date);
            if($date<=$availableToTimestamp && $date>=$availableFromTimestamp){
                $final_price = $offer->offer_price;
            }else{
                $final_price = $program->reservation_price;
            }
        }else{
            $final_price = $program->reservation_price;
        }


        return $final_price;
    }
}
