<?php

namespace App\Http\Controllers\api;

use App\Models\Coupons;
use App\Models\Customer;
use App\Models\UserCoupons;
use App\Traits\ApiResponseTrait;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use PhpParser\Node\Expr\Cast\Double;

class UserCopunsController extends Controller
{
    use ApiResponseTrait;


    // public function index()
    // {
    //     $coupons = UserCoupons::all();
    //     return view('system.customerCoupons.index', compact('coupons'));
    // }
    public function findUserCoupons(Request $request)
    {
        $rules = [
            "id" => "required",
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }
        try {
            $usercoupons = UserCoupons::where('user_id', $request->id)->get();
            $coupons = [];
            foreach ($usercoupons as $coupon) {
                // $coupon['customer'] = $coupon->Customer;
                $coupons[] = $coupon->Coupon;
            }
            return $this->returnData('coupons', $coupons, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no coupons");
        }
    }
    public function getPointBalance(Request $request)
    {
        $rules = [
            "user_id" => "required",
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }
        try {
            $balance = Customer::find($request->user_id)->points;
        
            return $this->returnData('points', $balance, "success");
        } catch (Exception $e) {
            return $this->error(0, "some thing went wrong");
        }
    }
    public function buyCoupon(Request $request)
    {
        $rules = [
            'user_id' => 'required|integer',
            'coupon_id' => 'required|integer',
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }
        try {
            $isExists = UserCoupons::where('coupon_id',$request->coupon_id)
                                    ->where('user_id',$request->user_id)
                                    ->get();
            if ($isExists) {
                return $this->error(0, "this coupon is already exists");
            }

            $customer = Customer::findOrFail($request->user_id);
            $cutomerPoints = doubleval($customer->points);

            $coupon = Coupons::findOrFail($request->coupon_id);
            $couponPoints = doubleval($coupon->points);

            if ($cutomerPoints >= $couponPoints) { //can buy
                $cutomerPoints = $cutomerPoints - $couponPoints;
                $new = UserCoupons::create($request->all());
                $newCoupon = $new->Coupon;
                $customer->points = $cutomerPoints;
                $customer->save();
                return $this->returnData('coupon', $newCoupon, "success");
            } else {
                return $this->error(0, "their is no enough points to buy this coupon");
            }
        } catch (Exception $e) {
            return $this->error(0, "some thing went wrong");
        }
    }

    public function create()
    {
        $coupons = Coupons::get();
        $customers = Customer::get();
        return view('system.customerCoupons.add', compact('coupons', 'customers'));
    }


    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|integer',
            'coupon_id' => 'required|integer',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        UserCoupons::create($request->all());
        session()->flash('Add', 'تم اضافة كوبون للمستخدم بنجاح ');

        return redirect()->route('customersCoupons.index')->with('success', 'User coupon created successfully.');
    }

    public function show($id)
    {
        $coupon = UserCoupons::findOrFail($id);
        return view('coupons.show', compact('coupon'));
    }


    public function edit($id)
    {
        $coupons = Coupons::get();
        $customers = Customer::get();
        $coupon = UserCoupons::findOrFail($id);
        return view('system.customerCoupons.edit', compact('coupon', 'coupons', 'customers'));
    }


    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|integer',
            'coupon_id' => 'required|integer',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        UserCoupons::findOrFail($id)->update($request->all());
        session()->flash('edit', 'تم تعديل كوبون المستخدم بنجاح ');

        return redirect()->route('customersCoupons.index')->with('success', 'User coupon updated successfully.');
    }


    public function destroy($id)
    {
        UserCoupons::findOrFail($id)->delete();
        session()->flash('delete', 'تم حذف كوبون المستخدم بنجاح ');
        return redirect()->route('customersCoupons.index')->with('success', 'User coupon deleted successfully.');
    }
}
