<?php

namespace App\Http\Controllers\api;

use App\Models\Customer;
use App\Models\favorite;
use App\Models\offer;
use App\Models\Program;
use App\Models\ProgramTypes;
use App\Traits\ApiResponseTrait;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Exception;

use function PHPUnit\Framework\isType;

class favoriteController extends Controller
{
    //
    use ApiResponseTrait;
    public function getMyFavorites(Request $request)
    {

        $rules = [
            "user_id" => "required",
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }
        try {
            $favorites = Favorite::where('user_id', $request->user_id)->get();
            $favs = [];
            foreach ($favorites as $favorite) {
                $favs[] = $favorite->type;
            }
            return $this->returnData('favorites', $favs, "success");
        } catch (Exception $e) {
            return $this->error(0, "their is no favorites");
        }
    }

    public function addToFavorites(Request $request)
    {

        $rules = [
            "user_id" => "required",
            "type_id" => "required",
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }
        try {

            $isType = ProgramTypes::find($request->type_id);
            $isCustomer = Customer::find($request->user_id);
            if ($isCustomer && $isType) {
                $isInFavorite = Favorite::where('user_id', $request->user_id)
                    ->where('type_id', $request->type_id)
                    ->exists();
                if ($isInFavorite) {
                    return $this->error(0, "this type is allready in favorites");
                } else {
                    Favorite::create($request->all());
                    return $this->success(0, "added to favorites successfully");
                }
            }
        } catch (Exception $e) {
            return $this->error(0, "their is no favorites");
        }
    }
    public function deleteFromFavorites(Request $request)
    {
        $rules = [
            "user_id" => "required",
            "type_id" => "required",
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            $code = $this->returnCodeAccordingToInput($validator);
            return $this->returnValidationError($code, $validator);
        }
        try {
            $fav = Favorite::where('user_id', $request->user_id)
                ->where('type_id', $request->type_id)->delete();

            return $this->success(0, "deleted from favorites successfully");
        } catch (Exception $e) {
            return $this->error(0, "some thing went wrong");
        }
    }
}
