<?php

namespace App\Http\Controllers;

use App\Models\Offer;
use App\Models\Program;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Exception;

class offerController extends Controller
{
    public function index()
    {
        $offers = Offer::all();

        return view('system.offers.index', compact('offers'));
    }

    public function create()
    {
        $programs = Program::all();
        return view('system.offers.add', compact('programs'));
    }
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'offer_price' => 'required',
            'offer_start_date' => 'required',
            'offer_end_date' => 'required',
            'status' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        try {

            $hasOffer=Offer::where('program_id',$request->program_id)->exists();
            if($hasOffer){
                session()->flash('failed', 'هذا العرض مسجل بالفعل');
                return redirect()->route('offers.index');
            }

            $offer = new Offer();
            $offer->program_id = $request->program_id;
            $offer->offer_price = $request->offer_price;
            $offer->offer_start_date = $request->offer_start_date;
            $offer->offer_end_date = $request->offer_end_date;
            $offer->status = $request->status;
            $offer->save();
            session()->flash('Add', 'تم اضافة العرض');
            return redirect()->route('offers.index')->with('success', 'Program created successfully.');
        } catch (Exception $e) {
            session()->flash('failed', 'فشل اضافة العرض');
            return redirect()->route('offers.index');
        }
    }

    public function show($id)
    {
        $offer = Offer::findOrFail($id);

        return view('system.offers.show', compact('offer'));
    }

    public function edit(Request $request, $id)
    {
        $programs = Program::all();

        $offer = Offer::findOrFail($id);
        return view('system.offers.edit', compact('offer','programs'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'offer_price' => 'required',
            'offer_start_date' => 'required',
            'offer_end_date' => 'required',
            'status' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Offer::findOrFail($id)->update($request->all());
        session()->flash('edit', 'تم تعديل العرض');

        return redirect()->route('offers.index')->with('success', 'Program updated successfully.');
    }

    public function destroy($id)
    {
        try {
            Offer::findOrFail($id)->delete();
            session()->flash('delete', 'تم حذف العرض');

            return redirect()->route('offers.index')->with('success', 'Program deleted successfully.');
        } catch (Exception $e) {
            session()->flash('failed', 'فشل حذف العرض');
            return redirect()->route('offers.index');

        }

    }

}
