<?php

use App\Http\Controllers\api\CouponsController;
use App\Http\Controllers\api\CustomerAuthController;
use App\Http\Controllers\api\favoriteController;
use App\Http\Controllers\api\offerController;
use App\Http\Controllers\api\ProgramController;
use App\Http\Controllers\api\ProgramTypesController;
use App\Http\Controllers\api\UserCopunsController;
use App\Http\Controllers\api\ReservationController;
use App\Http\Controllers\api\BannerController;
use App\Http\Middleware\isCustomerLoggedIn;
use App\Http\Middleware\IsCustomerVerified;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;


/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "api" middleware group. Make something great!
|
*/

Route::group(['middleware' => ['api']], function () {
    //auth
    Route::group(['prefix' => 'auth'], function () {
        Route::post('login', [CustomerAuthController::class, 'login']);
        Route::post('register', [CustomerAuthController::class, 'register']);
        Route::post('logout', [CustomerAuthController::class, 'logout']);
    });
    //programs
    Route::group(['prefix' => 'programs','middleware' => ['auth:sanctum',IsCustomerVerified::class]], function () {
        Route::get('get-all', [ProgramController::class, 'index']);
        Route::get('show-program', [ProgramController::class, 'show']);
        Route::get('show-program-from-fav', [ProgramController::class, 'showFromFav']);
    });

    //program types
    Route::group(['prefix' => 'program-types'], function () {
        Route::get('get-all', [ProgramTypesController::class, 'index']);
        Route::get('get-programs-with-type', [ProgramTypesController::class, 'getProgramsWithType']);
    });

    //coupons
    Route::group(['prefix' => 'coupons'], function () {
        Route::get('get-all', [CouponsController::class, 'index']);
        Route::get('get-my-coupons', [UserCopunsController::class, 'findUserCoupons']);
        Route::post('buy-coupon', [UserCopunsController::class, 'buyCoupon']);
        Route::post('point-balance', [UserCopunsController::class, 'getPointBalance']);
        // Route::get('show-program', [ProgramController::class, 'show']);
    });

    //favorites
    Route::group(['prefix' => 'favorites'], function () {
        Route::get('get-my-favorites', [favoriteController::class, 'getMyFavorites']);
        Route::post('add-to-favorites', [favoriteController::class, 'addToFavorites']);
        Route::post('delete-from-favorites', [favoriteController::class, 'deleteFromFavorites']);
        // Route::get('show-program', [ProgramController::class, 'show']);
    });

    //offers
    Route::group(['prefix' => 'offers'], function () {
        Route::get('last-offers', [offerController::class, 'getLastOffers']);
    });

    //reservations
    Route::group(['prefix' => 'reservations'], function () {
        Route::get('pending-reservation', [ReservationController::class, 'pending']);
        Route::post('add-reservation', [ReservationController::class, 'add']);
        Route::post('cancel-reservation', [ReservationController::class, 'cancel']);
        Route::get('view-reservation', [ReservationController::class, 'view']);
        Route::get('view-all-reservations', [ReservationController::class, 'viewAll']);
    });
    //banners
    Route::group(['prefix' => 'banners'], function () {
        Route::get('get-all-banners', [BannerController::class, 'getAll']);
    });

});
